# -*- coding: utf-8 -*-

# This file is part of Pigeon Planner.

# Pigeon Planner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# Pigeon Planner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Pigeon Planner.  If not, see <http://www.gnu.org/licenses/>

import logging

from peewee import TextField
from playhouse.migrate import migrate, SqliteMigrator

logger = logging.getLogger(__name__)

database_version = 4


def do_migration(db):
    migrator = SqliteMigrator(db)

    logger.info("Adding 'extra' column")
    extra_field = TextField(default="")
    migrate(
        migrator.add_column("pigeon", "extra", extra_field),
    )

    logger.info("Merging data from all 'extraN' columns into 'extra' column")
    db.execute_sql("""
        UPDATE pigeon SET extra =
            extra1 || '\n' || extra2 || '\n' || extra3 || '\n' || extra4 || '\n' || extra5 || '\n' || extra6
    """)

    logger.info("Trimming trailing newlines")
    db.execute_sql("UPDATE pigeon SET extra = rtrim(extra, '\n')")

    logger.info("Dropping old 'extraN' columns")
    migrate(
        migrator.drop_column("pigeon", "extra1"),
        migrator.drop_column("pigeon", "extra2"),
        migrator.drop_column("pigeon", "extra3"),
        migrator.drop_column("pigeon", "extra4"),
        migrator.drop_column("pigeon", "extra5"),
        migrator.drop_column("pigeon", "extra6"),
    )
